@@ -120,7 +120,7 @@ class Client(object):
             return self.ping(retry=False)
         return ret == protocol.RES_OK
 
-    def put(self, key, source, retry=True):
+    def put_stat(self, key, source, retry=True):
         close = False
         if not hasattr(source, 'read'):
             source = open(source, 'rb')
@@ -130,30 +130,35 @@ class Client(object):
         source.seek(0)
         sock = self._socket()
         if sock is None:
-            return False
+            return None
         request = self._request(protocol.CMD_PUT, args=(self.domain, key,))
         if not self._write(sock, request):
-            return False
+            return None
         ret = self._read(sock, 1)
         if ret is None and retry:
-            return self.put(key, source, retry=False)
+            return self.put_stat(key, source, retry=False)
         elif ret != protocol.RES_WAITING:
-            return False
+            return None
         if not self._write(sock, struct.pack('I', size)):
-            return False
+            return None
         digest = md5()
         while True:
             data = source.read(protocol.BLOCKSIZE)
             if not data:
                 break
             if not self._write(sock, data):
-                return False
+                return None
             digest.update(data)
         if close:
             source.close()
         if not self._write(sock, digest.hexdigest()):
-            return False
-        return self._read(sock, 1) == protocol.RES_OK
+            return None
+        if self._read(sock, 1) != protocol.RES_OK:
+            return None
+        return {'digest': digest, 'size': size}
+
+    def put(self, key, source):
+        return self.put_stat(key, source) is not None
 
     def get(self, key, destination, sock=None, retry=True):
         if sock is None:
@@ -281,6 +286,9 @@ class ClientPool(object):
     def put(self, key, source):
         return self.client.put(str(key), source)
 
+    def put_stat(self, key, source):
+        return self.client.put_stat(str(key), source)
+
     def get(self, key, destination):
         return self.client.get(str(key), destination)
 
@@ -336,6 +344,10 @@ class TransactionalClientPool(ClientPool):
         self.join()
         return super(TransactionalClientPool, self).put(key, source)
 
+    def put_stat(self, key, source):
+        self.join()
+        return super(TransactionalClientPool, self).put_stat(key, source)
+
     def join(self):
         if not getattr(self.client, 'transaction', None):
             tx = transaction.get()
