@@ -16,10 +16,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+import doctest
 import unittest
 
-from zope.testing import doctest
-
 
 docfiles = [
     'tests.txt',
